==> tine20-exampleapplication_2016.11.24.tar.bz2: ExampleApplication/js/ExampleApplication-lang-ru-debug.js <==
/********************** tine translations of ExampleApplication**********************/ 
Locale.Gettext.prototype._msgs['./LC_MESSAGES/ExampleApplication'] = new Locale.Gettext.PO(({
""
: "Project-Id-Version: Tine 2.0 - ExampleApplication\nReport-Msgid-Bugs-To: \nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2012-03-02 13:03+0000\nLast-Translator: Nkolay Parukhin <Unknown>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\nX-Launchpad-Export-Date: 2012-03-03 05:53+0000\nX-Generator: Launchpad (build 14886)\nX-Poedit-Language: Russian\nX-Poedit-SourceCharset: utf-8\n"

, "Status Available"
: ""

, "Possible status. Please note that additional status might impact other ExampleApplication systems on export or syncronisation."
: ""

, "%s's personal example records"
: ""

, "Example Application test"
: ""

, "ExampleRecord"
: ""

, "Name"
: ""

, "Status"
: "Статус"

, "Title"
: "Заголовок"

, "Budget"
: "Бюджет"

, "Show closed"
: "Показать закрытые"

, "example record, example records"
: [
  ""
 ,""

]
, "example record list, example record lists"
: [
  ""
 ,""

]
, "Quick Search"
: ""

, "Last modified"
: ""

, "Last modifier"
: ""

, "Creation Time"
: ""

, "Creator"
: ""

, "Completed"
: ""

, "Cancelled"
: ""

, "In process"
: ""

, "ExampleApplication"
: "ПриложениеПример"

, "ExampleRecords"
: "ЗаписиПримеры"

, "All ExampleRecords"
: "Все ЗаписиПримеры"

, "Description"
: "Описание"

, "record list, record lists"
: [
  "список записей"
 ,"списка записей"
 ,"списков записей"

]
, "Number"
: "Номер"

, "Unit"
: "Единица"

, "Unit Price"
: "Цена за единицу"

, "Timesheets are billable"
: "Табели оплачиваемы"

, "closed"
: "закрыт"

, "open"
: "открыт"

, "Billed"
: "Оплачен"

, "not yet billed"
: "ещё не оплачен"

, "to bill"
: "к оплате"

, "billed"
: "оплачен"

, "example record"
: ""

, "example record list"
: ""

, "record list"
: "список записей"

}));

==> tine20-exampleapplication_2017.08.11.tar.bz2: ExampleApplication/js/ExampleApplication-lang-ru-debug.js <==
/********************** tine translations of ExampleApplication**********************/ 
Locale.Gettext.prototype._msgs['./LC_MESSAGES/ExampleApplication'] = new Locale.Gettext.PO(({
""
: "Project-Id-Version: Tine 2.0 - ExampleApplication\nReport-Msgid-Bugs-To: \nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2012-03-02 13:03+0000\nLast-Translator: Nkolay Parukhin <Unknown>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\nX-Launchpad-Export-Date: 2012-03-03 05:53+0000\nX-Generator: Launchpad (build 14886)\nX-Poedit-Language: Russian\nX-Poedit-SourceCharset: utf-8\n"

, "ExampleRecord"
: ""

, "Name"
: ""

, "Status"
: "Статус"

, "Reason"
: ""

, "Total Example Records"
: ""

, "New Example"
: ""

, "Status Available"
: ""

, "Possible status. Please note that additional status might impact other ExampleApplication systems on export or syncronisation."
: ""

, "Completed"
: ""

, "Cancelled"
: ""

, "In process"
: ""

, "Reasons Available"
: ""

, "Possible status reasons."
: ""

, "Change"
: ""

, "Documentation"
: ""

, "Requirement Changed"
: ""

, "Not Possible"
: ""

, "Implementation"
: ""

, "Review"
: ""

, "Integration"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Sales Application."
: ""

, "Invoices Module"
: ""

, "Example String"
: ""

, "Just an example string for test purpose"
: ""

, "ExampleApplication"
: "ПриложениеПример"

, "example record, example records"
: [
  ""
 ,""

]
, "example records"
: ""

, "example record list"
: ""

, "example record lists"
: ""

, "Number"
: "Номер"

, "Default Example Record Container"
: ""

, "The default container for new records"
: ""

















, "example record"
: ""

}));
